Range-v3: ranges::v3::iter_distance_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::iter_distance_fn Struct Reference
Utility
Inheritance diagram for ranges::v3::iter_distance_fn:

## Public Member Functions
template<typename I , typename S , typename D = difference_type_t<I>, requires = (Iterator<I>() && Sentinel<S, I>() && Integral<D>())>
D | operator() (I begin, S end, D d=0) const